/*******************************************************************************
 *
 * blueMarine - open source photo workflow
 * =======================================
 *
 * Copyright (C) 2003-2010 by Fabrizio Giudici
 * Project home page: http://bluemarine.tidalwave.it
 *
 *******************************************************************************
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); 
 * you may not use this file except in compliance with the License. 
 * You may obtain a copy of the License at 
 * 
 *     http://www.apache.org/licenses/LICENSE-2.0 
 * 
 * Unless required by applicable law or agreed to in writing, software 
 * distributed under the License is distributed on an "AS IS" BASIS, 
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. 
 * See the License for the specific language governing permissions and 
 * limitations under the License. 
 *
 *******************************************************************************
 *
 * $Id: AllTypesNode.java,v 213fe927a495 2010/01/01 00:36:29 fabrizio $
 *
 ******************************************************************************/
package it.tidalwave.semantic.node.impl;

import javax.annotation.Nonnull;
import java.util.logging.Logger;
import java.util.Set;
import java.io.IOException;
import org.openide.util.NbBundle;
import it.tidalwave.semantic.other.Repository;
import it.tidalwave.semantic.other.Type;

/*******************************************************************************
 * 
 * This class represents the root node which contains all root categories. It is
 * also responsible for listening to the Catalog for any category change and 
 * update the nodes accordingly (with this approach, a single listener to the
 * Catalog is used instead of one for each node).
 * 
 * @author  Fabrizio Giudici
 * @version $Id: AllTypesNode.java,v 213fe927a495 2010/01/01 00:36:29 fabrizio $
 *
 ******************************************************************************/
public class AllTypesNode extends TypeNode
  {
    private final static String CLASS = AllTypesNode.class.getName();
    private final static Logger logger = Logger.getLogger(CLASS);

    @Nonnull
    private final Repository repository;

    @Nonnull
    private final TypeChildFactory childFactory;

    /***************************************************************************
     *
     *
     **************************************************************************/
    protected static class TypeChildFactory extends TypeNode.TypeChildFactory
      {
        @Nonnull
        private final Repository repository;

        public TypeChildFactory (@Nonnull final Repository repository)
          {
//            super(null, new NodeFinder());
            super(null);
            this.repository = repository;
          }
        
        @Override
        @Nonnull
        protected Set<Type> findTypes()
          {
            final Set<Type> types = repository.getAllTypes();
//            final Collator collator = Collator.getInstance();
//            Collections.sort(types, new Comparator<Type>()
//              {
//                public int compare (final Type c1, final Type c2)
//                  {
//                    return collator.compare(c1.getDisplayName(), c2.getDisplayName());
//                  }
//              });
              
            return types;
          }
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    public AllTypesNode (@Nonnull final Repository repository)
      {
        this(repository, new TypeChildFactory(repository));
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    private AllTypesNode (@Nonnull final Repository repository,
                          @Nonnull final TypeChildFactory childFactory)
      {
        super(childFactory);
        this.repository = repository;
        this.childFactory = childFactory;
        setName(NbBundle.getMessage(AllTypesNode.class, "FN_AllCategories"));
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public void destroy() 
      throws IOException
      {
//        repository.removeListener(repositoryListener);
        super.destroy();
      }

    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public boolean canCopy()
      {
        return false;
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public boolean canCut()
      {
        return false;
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public boolean canDestroy()
      {
        return false;
      }
    
    /***************************************************************************
     *
     *
     **************************************************************************/
    @Override
    public boolean canRename()
      {
        return false;
      }
  }
